<?php
    
    namespace backend\models;
    
    use common\modules\language\models\Language;
    use Yii;
    use yii\db\ActiveRecord;
    
    /**
     * This is the model class for table "orders_label_lang".
     * @property integer  $orders_label_id
     * @property integer  $language_id
     * @property string   $name
     * @property Language $language
     * @property Label    $label
     */
    class OrdersLabelLang extends ActiveRecord
    {
        
        public static function primaryKey()
        {
            return [
                'orders_label_id',
                'language_id',
            ];
        }
        
        /**
         * @inheritdoc
         */
        public static function tableName()
        {
            return 'orders_label_lang';
        }
        
        /**
         * @inheritdoc
         */
        public function rules()
        {
            return [
                [
                    [ 'name' ],
                    'required',
                ],
                [
                    [ 'name' ],
                    'string',
                    'max' => 255,
                ],
                [
                    [
                        'orders_label_id',
                        'language_id',
                    ],
                    'unique',
                    'targetAttribute' => [
                        'orders_label_id',
                        'language_id',
                    ],
                    'message'         => 'The combination of Orders Label ID and Language ID has already been taken.',
                ],
                [
                    [ 'language_id' ],
                    'exist',
                    'skipOnError'     => true,
                    'targetClass'     => Language::className(),
                    'targetAttribute' => [ 'language_id' => 'language_id' ],
                ],
                [
                    [ 'orders_label_id' ],
                    'exist',
                    'skipOnError'     => true,
                    'targetClass'     => Label::className(),
                    'targetAttribute' => [ 'orders_label_id' => 'id' ],
                ],
            ];
        }
        
        /**
         * @inheritdoc
         */
        public function attributeLabels()
        {
            return [
                'orders_label_id' => Yii::t('app', 'Orders Label ID'),
                'language_id'     => Yii::t('app', 'Language ID'),
                'name'            => Yii::t('app', 'Name'),
            ];
        }
        
        /**
         * @return \yii\db\ActiveQuery
         */
        public function getLanguage()
        {
            return $this->hasOne(Language::className(), [ 'language_id' => 'language_id' ]);
        }
        
        /**
         * @return \yii\db\ActiveQuery
         */
        public function getLabel()
        {
            return $this->hasOne(Label::className(), [ 'id' => 'orders_label_id' ]);
        }
    }
