<?php
    
    namespace common\behaviors;
    
    use yii\base\Behavior;
    use yii\base\Event;
    use yii\db\ActiveRecord;
    
    /**
     * Class ImageBehavior
     *
     * @package common\behaviors
     */
    class ImageBehavior extends Behavior
    {
        
        /**
         * @var string column where file name is stored
         */
        public $link;
        
        /**
         * @var string directory name
         */
        public $directory;
        
        /**
         * @inheritdoc
         */
        public function events()
        {
            return [
                ActiveRecord::EVENT_BEFORE_DELETE => 'beforeDelete',
            ];
        }
        
        /**
         * @param Event $event
         */
        public function beforeDelete($event)
        {
            $file = $this->getImageFile();
            if (file_exists($file)) {
                unlink($file);
            }
        }
        
        /**
         * Get image file path
         *
         * @return null|string
         */
        public function getImageFile()
        {
            $link = $this->link;
            return empty( $this->owner->$link ) ? null : \Yii::getAlias(
                '@storage/' . $this->directory . '/' . $this->owner->$link
            );
        }
        
        /**
         * Get image file url
         *
         * @param bool $dummy
         *
         * @return null|string
         */
        public function getImageUrl($dummy = true)
        {
            $link = $this->link;
            if (!empty( $this->owner->$link )) {
                return '/storage/' . $this->directory . '/' . $this->owner->$link;
            } elseif ($dummy) {
                return '/storage/no-image.png';
            } else {
                return null;
            }
        }
    }