<?php
    
    namespace common\models;
    
    use common\modules\language\behaviors\LanguageBehavior;
    use common\behaviors\SaveImgBehavior;
    use common\modules\comment\models\CommentModel;
    use Yii;
    use yii\db\ActiveQuery;
    use yii\db\ActiveRecord;
    use yii\web\Request;
    
    /**
     * This is the model class for table "articles".
     * @property integer        $id
     * @property integer        $date
     * @property string         $image
     * * From language behavior *
     * @property ArticlesLang   $lang
     * @property ArticlesLang[] $langs
     * @property ArticlesLang   $object_lang
     * @property string         $ownerKey
     * @property string         $langKey
     * @property ArticlesLang[] $model_langs
     * @property bool           $transactionStatus
     * @method string           getOwnerKey()
     * @method void             setOwnerKey( string $value )
     * @method string           getLangKey()
     * @method void             setLangKey( string $value )
     * @method ActiveQuery      getLangs()
     * @method ActiveQuery      getLang( integer $language_id )
     * @method ArticlesLang[]   generateLangs()
     * @method void             loadLangs( Request $request )
     * @method bool             linkLangs()
     * @method bool             saveLangs()
     * @method bool             getTransactionStatus()
     * * End language behavior *
     * * From SaveImgBehavior
     * @property string|null    imageFile
     * @property string|null    imageUrl
     * @method string|null getImageFile( int $field )
     * @method string|null getImageUrl( int $field )
     * * End SaveImgBehavior
     */
    class Articles extends ActiveRecord
    {
        
        /**
         * @inheritdoc
         */
        public static function tableName()
        {
            return 'articles';
        }
        
        /**
         * @inheritdoc
         */
        public function behaviors()
        {
            return [
                [
                    'class'  => SaveImgBehavior::className(),
                    'fields' => [
                        [
                            'name'      => 'image',
                            'directory' => 'articles',
                        ],
                    ],
                ],
                'language' => [
                    'class' => LanguageBehavior::className(),
                ],
            ];
        }
        
        /**
         * @inheritdoc
         */
        public function rules()
        {
            return [
                [
                    [ 'date' ],
                    'default',
                    'value' => function() {
                        return time();
                    },
                ],
                [
                    [ 'date' ],
                    'safe',
                ],
                [
                    [ 'date' ],
                    'filter',
                    'filter' => function($value) {
                        return strtotime($value) ? : time();
                    },
                ],
            ];
        }
        
        /**
         * @inheritdoc
         */
        public function attributeLabels()
        {
            return [
                'id'       => Yii::t('app', 'ID'),
                'date'     => Yii::t('app', 'Date'),
                'image'    => Yii::t('app', 'Image'),
                'imageUrl' => Yii::t('app', 'Image'),
            ];
        }
        
        public function recalculateRating()
        {
            /**
             * @var ArticleToRating $averageRating
             */
            $average = $this->getComments()
                            ->joinWith('rating')
                            ->select([ 'average' => 'avg(artbox_comment_rating.value)::float' ])
                            ->scalar();
            if(!$average) {
                $average = 0;
            }
            $averageRating = $this->averageRating;
            if(!empty( $averageRating )) {
                $averageRating->value = $average;
            } else {
                $averageRating = new ArticleToRating([
                    'articles_id' => $this->id,
                    'value'       => $average,
                ]);
            }
            if($averageRating->save()) {
                return true;
            } else {
                return false;
            }
        }
        
        public function getComments()
        {
            return $this->hasMany(CommentModel::className(), [ 'entity_id' => 'id' ])
                        ->where([
                            'artbox_comment.entity'             => self::className(),
                            'artbox_comment.status'             => CommentModel::STATUS_ACTIVE,
                            'artbox_comment.artbox_comment_pid' => NULL,
                        ]);
        }
        
        public function getAverageRating()
        {
            return $this->hasOne(ArticleToRating::className(), [ 'articles_id' => 'id' ]);
        }
    }
