<?php

namespace common\models;

use common\modules\language\models\Language;
use Yii;

/**
 * This is the model class for table "articles_lang".
 *
 * @property integer $articles_id
 * @property integer $language_id
 * @property string $title
 * @property string $body
 * @property string $meta_title
 * @property string $meta_keywords
 * @property string $meta_description
 * @property string $seo_text
 * @property string $h1
 * @property string $body_preview
 * @property string $alias
 *
 * @property Articles $articles
 * @property Language $language
 */
class ArticlesLang extends \yii\db\ActiveRecord
{
    public static function primaryKey()
    {
        return [
            'articles_id',
            'language_id',
        ];
    }
    
    /**
     * @inheritdoc
     */
    public static function tableName()
    {
        return 'articles_lang';
    }

    public function behaviors()
    {
        return [
            'slug'     => [
                'class'         => 'common\behaviors\Slug',
                'in_attribute'  => 'title',
                'out_attribute' => 'alias',
                'translit'      => true,
            ],
        ];
    }
    
    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            [['title', 'body'], 'required'],
            [['body', 'seo_text', 'body_preview', 'alias'], 'string'],
            [['title', 'meta_title', 'meta_keywords', 'meta_description', 'h1'], 'string', 'max' => 255],
            [['articles_id', 'language_id'], 'unique', 'targetAttribute' => ['articles_id', 'language_id'], 'message' => 'The combination of Articles ID and Language ID has already been taken.'],
            [['articles_id'], 'exist', 'skipOnError' => true, 'targetClass' => Articles::className(), 'targetAttribute' => ['articles_id' => 'id']],
            [['language_id'], 'exist', 'skipOnError' => true, 'targetClass' => Language::className(), 'targetAttribute' => ['language_id' => 'language_id']],
        ];
    }

    /**
     * @inheritdoc
     */
    public function attributeLabels()
    {
        return [
            'articles_id' => Yii::t('app', 'lang-Articles ID'),
            'language_id' => Yii::t('app', 'lang-Language ID'),
            'title' => Yii::t('app', 'lang-Title'),
            'body' => Yii::t('app', 'lang-Body'),
            'meta_title' => Yii::t('app', 'lang-Meta Title'),
            'meta_keywords' => Yii::t('app', 'lang-Meta Keywords'),
            'meta_description' => Yii::t('app', 'lang-Meta Description'),
            'seo_text' => Yii::t('app', 'lang-Seo Text'),
            'h1' => Yii::t('app', 'lang-H1'),
            'body_preview' => Yii::t('app', 'lang-Body Preview'),
        ];
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getArticles()
    {
        return $this->hasOne(Articles::className(), ['id' => 'articles_id'])->inverseOf('langs');
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getLanguage()
    {
        return $this->hasOne(Language::className(), ['language_id' => 'language_id']);
    }
}
