<?php

namespace common\models;

use common\behaviors\SaveImgBehavior;
use common\modules\language\models\Language;
use Yii;

/**
 * This is the model class for table "banner_lang".
 *
 * @property integer $banner_id
 * @property integer $language_id
 * @property string $alt
 * @property string $title
 * @property string $image
 *
 * @property Banner $banner
 * @property Language $language
 */
class BannerLang extends \yii\db\ActiveRecord
{
    
    public static function primaryKey()
    {
        return [
            'banner_id',
            'language_id',
        ];
    }
    
    /**
     * @inheritdoc
     */
    public static function tableName()
    {
        return 'banner_lang';
    }
    
    public function behaviors()
    {
        return [
            [
                'class' => SaveImgBehavior::className(),
                'is_language' => true,
                'fields' => [
                    [
                        'name' => 'image',
                        'directory' => 'banner',
                    ],
                ],
            ]
        ];
    }
    
    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            [['alt', 'title', 'image'], 'string', 'max' => 255],
            [['banner_id', 'language_id'], 'unique', 'targetAttribute' => ['banner_id', 'language_id'], 'message' => 'The combination of Banner ID and Language ID has already been taken.'],
            [['banner_id'], 'exist', 'skipOnError' => true, 'targetClass' => Banner::className(), 'targetAttribute' => ['banner_id' => 'banner_id']],
            [['language_id'], 'exist', 'skipOnError' => true, 'targetClass' => Language::className(), 'targetAttribute' => ['language_id' => 'language_id']],
        ];
    }

    /**
     * @inheritdoc
     */
    public function attributeLabels()
    {
        return [
            'banner_id' => Yii::t('app', 'banner_id'),
            'language_id' => Yii::t('app', 'language_id'),
            'alt' => Yii::t('app', 'alt'),
            'title' => Yii::t('app', 'title'),
        ];
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getBanner()
    {
        return $this->hasOne(Banner::className(), ['banner_id' => 'banner_id']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getLanguage()
    {
        return $this->hasOne(Language::className(), ['language_id' => 'language_id']);
    }
}
