<?php

namespace common\models;

use Yii;
use yii\behaviors\AttributeBehavior;
use yii\behaviors\TimestampBehavior;
use yii\db\ActiveRecord;

/**
 * This is the model class for table "feedback".
 *
 * @property integer $feedback_id
 * @property string $name
 * @property string $phone
 * @property integer $date_add
 * @property string $ip
 */
class Feedback extends \yii\db\ActiveRecord
{
    
    const SCENARIO_FEEDBACK = 'feedback';
    const SCENARIO_CALLBACK = 'callback';
    
    /**
     * @inheritdoc
     */
    public static function tableName()
    {
        return 'feedback';
    }
    
    /**
     * @inheritdoc
     */
    public function scenarios()
    {
        $scenarios = parent::scenarios();
        $scenarios = array_merge($scenarios, [
            self::SCENARIO_FEEDBACK => ['name', 'phone'],
            self::SCENARIO_CALLBACK => ['phone'],
        ]);
        return  $scenarios;
    }
    
    /**
     * @inheritdoc
     */
    public function behaviors()
    {
        return [
            [
                'class' => TimestampBehavior::className(),
                'createdAtAttribute' => 'date_add',
                'updatedAtAttribute' => false,
            ],
            [
                'class' => AttributeBehavior::className(),
                'attributes' => [
                    ActiveRecord::EVENT_BEFORE_INSERT => 'ip',
                ],
                'value' => function($event) {
                    return \Yii::$app->request->userIP;
                },
            ]
        ];
    }
    
    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            [['phone', 'name'], 'required'],
            [['phone'], 'match', 'pattern' => '/^\+38\(\d{3}\)\d{3}-\d{2}-\d{2}$/'],
            [['name', 'phone'], 'string', 'max' => 255],
        ];
    }

    /**
     * @inheritdoc
     */
    public function attributeLabels()
    {
        return [
            'feedback_id' => Yii::t('app', 'feedback_id'),
            'name' => Yii::t('app', 'name'),
            'phone' => Yii::t('app', 'phone'),
            'date_add' => Yii::t('app', 'date_add'),
            'ip' => Yii::t('app', 'ip'),
        ];
    }
}
