<?php
    
    namespace common\models;
    
    use yii\base\Model;
    use yii\data\ActiveDataProvider;
    
    /**
     * ProjectSearch represents the model behind the search form about `common\models\Project`.
     */
    class ProjectSearch extends Project
    {
        
        public $title;
        
        public function behaviors()
        {
            return [];
        }
        
        /**
         * @inheritdoc
         */
        public function rules()
        {
            return [
                [
                    [
                        'project_id',
                        'date_add',
                    ],
                    'integer',
                ],
                [
                    [ 'title' ],
                    'safe',
                ],
            ];
        }
        
        /**
         * @inheritdoc
         */
        public function scenarios()
        {
            // bypass scenarios() implementation in the parent class
            return Model::scenarios();
        }
        
        /**
         * Creates data provider instance with search query applied
         *
         * @param array $params
         *
         * @return ActiveDataProvider
         */
        public function search($params)
        {
            $query = Project::find()
                            ->joinWith('lang');
            
            // add conditions that should always apply here
            
            $dataProvider = new ActiveDataProvider(
                [
                    'query' => $query,
                    'sort'  => [
                        'attributes'   => [
                            'project_id',
                            'date_add',
                            'title' => [
                                'asc'  => [ 'project_lang.title' => SORT_ASC ],
                                'desc' => [ 'project_lang.title' => SORT_DESC ],
                            ],
                        ],
                        'defaultOrder' => [
                            'date_add' => SORT_DESC,
                        ],
                    ],
                ]
            );
            
            $this->load($params);
            
            if (!$this->validate()) {
                // uncomment the following line if you do not want to return any records when validation fails
                // $query->where('0=1');
                return $dataProvider;
            }
            
            // grid filtering conditions
            $query->andFilterWhere(
                [
                    'project_id' => $this->project_id,
                    'date_add'   => $this->date_add,
                ]
            );
            
            $query->andFilterWhere(
                [
                    'like',
                    'project_lang.title',
                    $this->title,
                ]
            );
            
            return $dataProvider;
        }
    }
