<?php
    
    namespace common\modules\product\models;
    
    use common\behaviors\SaveImgBehavior;
    use common\modules\language\behaviors\LanguageBehavior;
    use Yii;
    use yii\db\ActiveQuery;
    use yii\db\ActiveRecord;
    use yii\web\Request;
    
    /**
     * This is the model class for table "brand".
     * @property integer     $brand_id
     * @property string      $image
     * @property bool        $in_menu
     * @property Product[]   $products
     * * From language behavior *
     * @property BrandLang   $lang
     * @property BrandLang[] $langs
     * @property BrandLang   $object_lang
     * @property string      $ownerKey
     * @property string      $langKey
     * @property BrandLang[] $model_langs
     * @property bool        $transactionStatus
     * @method string           getOwnerKey()
     * @method void             setOwnerKey( string $value )
     * @method string           getLangKey()
     * @method void             setLangKey( string $value )
     * @method ActiveQuery      getLangs()
     * @method ActiveQuery      getLang( integer $language_id )
     * @method BrandLang[]    generateLangs()
     * @method void             loadLangs( Request $request )
     * @method bool             linkLangs()
     * @method bool             saveLangs()
     * @method bool             getTransactionStatus()
     * * End language behavior *
     */
    class Brand extends ActiveRecord
    {
        
        public $_items_count = 0;
        
        /**
         * @inheritdoc
         */
        public static function tableName()
        {
            return 'brand';
        }
        
        public function behaviors()
        {
            return [
                [
                    'class'  => SaveImgBehavior::className(),
                    'fields' => [
                        [
                            'name'      => 'image',
                            'directory' => 'brand',
                        ],
                    ],
                ],
                'language' => [
                    'class' => LanguageBehavior::className(),
                ],
            ];
        }
        
        /**
         * @inheritdoc
         */
        public function rules()
        {
            return [
                [
                    [ 'in_menu' ],
                    'boolean',
                ],
            ];
        }
        
        /**
         * @inheritdoc
         */
        public function attributeLabels()
        {
            return [
                'brand_id' => Yii::t('product', 'Brand ID'),
                'image'    => Yii::t('product', 'Image'),
            ];
        }
        
        /**
         * @return \yii\db\ActiveQuery
         */
        public function getProducts()
        {
            return $this->hasMany(Product::className(), [ 'brand_id' => 'brand_id' ]);
        }
    }
