<?php
    
    namespace common\modules\product\models;
    
    use common\modules\language\models\Language;
    use Yii;
    
    /**
     * This is the model class for table "brand_lang".
     * @property integer  $brand_id
     * @property integer  $language_id
     * @property string   $name
     * @property string   $meta_title
     * @property string   $meta_robots
     * @property string   $meta_desc
     * @property string   $seo_text
     * @property string   $alias
     * @property Brand    $brand
     * @property Language $language
     */
    class BrandLang extends \yii\db\ActiveRecord
    {
        
        public static function primaryKey()
        {
            return [
                'brand_id',
                'language_id',
            ];
        }
        
        /**
         * @inheritdoc
         */
        public static function tableName()
        {
            return 'brand_lang';
        }
        
        public function behaviors()
        {
            return [
                'slug' => [
                    'class'         => 'common\behaviors\Slug',
                    'in_attribute'  => 'name',
                    'out_attribute' => 'alias',
                    'translit'      => true,
                ],
            ];
        }
        
        /**
         * @inheritdoc
         */
        public function rules()
        {
            return [
                [
                    [ 'name' ],
                    'required',
                ],
                [
                    [ 'seo_text' ],
                    'string',
                ],
                [
                    [
                        'name',
                        'meta_title',
                        'meta_robots',
                        'meta_desc',
                        'alias',
                    ],
                    'string',
                    'max' => 255,
                ],
                [
                    [
                        'brand_id',
                        'language_id',
                    ],
                    'unique',
                    'targetAttribute' => [
                        'brand_id',
                        'language_id',
                    ],
                    'message'         => 'The combination of Brand ID and Language ID has already been taken.',
                ],
                [
                    [ 'brand_id' ],
                    'exist',
                    'skipOnError'     => true,
                    'targetClass'     => Brand::className(),
                    'targetAttribute' => [ 'brand_id' => 'brand_id' ],
                ],
                [
                    [ 'language_id' ],
                    'exist',
                    'skipOnError'     => true,
                    'targetClass'     => Language::className(),
                    'targetAttribute' => [ 'language_id' => 'language_id' ],
                ],
            ];
        }
        
        /**
         * @inheritdoc
         */
        public function attributeLabels()
        {
            return [
                'brand_id'    => Yii::t('app', 'Brand ID'),
                'language_id' => Yii::t('app', 'Language ID'),
                'name'        => Yii::t('app', 'Name'),
                'meta_title'  => Yii::t('app', 'Meta Title'),
                'meta_robots' => Yii::t('app', 'Meta Robots'),
                'meta_desc'   => Yii::t('app', 'Meta Desc'),
                'seo_text'    => Yii::t('app', 'Seo Text'),
                'alias'       => Yii::t('app', 'Alias'),
            ];
        }
        
        /**
         * @return \yii\db\ActiveQuery
         */
        public function getBrand()
        {
            return $this->hasOne(Brand::className(), [ 'brand_id' => 'brand_id' ]);
        }
        
        /**
         * @return \yii\db\ActiveQuery
         */
        public function getLanguage()
        {
            return $this->hasOne(Language::className(), [ 'language_id' => 'language_id' ]);
        }
    }
