<?php

namespace common\modules\product\models;

/**
 * This is the model class for table "product_stock".
 *
 * @property integer $product_id
 * @property integer $stock_id
 * @property integer $quantity
 * @property integer $product_variant_id
 *
 * @property Product $product
 * @property ProductVariant $productVariant
 * @property Stock $stock
 */
class ProductStock extends \yii\db\ActiveRecord
{
    /**
     * @inheritdoc
     */
    public static function tableName()
    {
        return 'product_stock';
    }

    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            [['product_id', 'stock_id', 'quantity', 'product_variant_id'], 'integer'],
            [['name'],'required'],
            [['product_id'], 'exist', 'skipOnError' => true, 'targetClass' => Product::className(), 'targetAttribute' => ['product_id' => 'product_id']],
            [['product_variant_id'], 'exist', 'skipOnError' => true, 'targetClass' => ProductVariant::className(), 'targetAttribute' => ['product_variant_id' => 'product_variant_id']],
            [['stock_id'], 'exist', 'skipOnError' => true, 'targetClass' => Stock::className(), 'targetAttribute' => ['stock_id' => 'stock_id']],
        ];
    }

    /**
     * @inheritdoc
     */
    public function attributeLabels()
    {
        return [
            'product_id' => 'Product ID',
            'stock_id' => 'Stock ID',
            'quantity' => 'Количество',
            'product_variant_id' => 'Product Variant ID',
            'name' => "Название"
        ];
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getProduct()
    {
        return $this->hasOne(Product::className(), ['product_id' => 'product_id']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getProductVariant()
    {
        return $this->hasOne(ProductVariant::className(), ['product_variant_id' => 'product_variant_id']);
    }


    public function getName(){
        return (!empty($this->stock))?  $this->stock->lang->name : '';
    }

    public function setName($value){
        $this->name = $value;
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getStock()
    {
        return $this->hasOne(Stock::className(), ['stock_id' => 'stock_id']);
    }


    public static function primaryKey()
    {
        return ["stock_id","product_variant_id"];
    }
}
