<?php

namespace common\modules\product\models;

use common\modules\language\models\Language;
use Yii;

/**
 * This is the model class for table "product_variant_lang".
 *
 * @property integer $product_variant_id
 * @property integer $language_id
 * @property string $name
 *
 * @property Language $language
 * @property ProductVariant $productVariant
 */
class ProductVariantLang extends \yii\db\ActiveRecord
{
    
    public static function primaryKey()
    {
        return [
            'product_variant_id',
            'language_id',
        ];
    }
    
    /**
     * @inheritdoc
     */
    public static function tableName()
    {
        return 'product_variant_lang';
    }

    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            [['name'], 'required'],
            [['name'], 'string', 'max' => 255],
            [['product_variant_id', 'language_id'], 'unique', 'targetAttribute' => ['product_variant_id', 'language_id'], 'message' => 'The combination of Product Variant ID and Language ID has already been taken.'],
            [['language_id'], 'exist', 'skipOnError' => true, 'targetClass' => Language::className(), 'targetAttribute' => ['language_id' => 'language_id']],
            [['product_variant_id'], 'exist', 'skipOnError' => true, 'targetClass' => ProductVariant::className(), 'targetAttribute' => ['product_variant_id' => 'product_variant_id']],
        ];
    }

    /**
     * @inheritdoc
     */
    public function attributeLabels()
    {
        return [
            'product_variant_id' => Yii::t('app', 'Product Variant ID'),
            'language_id' => Yii::t('app', 'Language ID'),
            'name' => Yii::t('app', 'Name'),
        ];
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getLanguage()
    {
        return $this->hasOne(Language::className(), ['language_id' => 'language_id']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getProductVariant()
    {
        return $this->hasOne(ProductVariant::className(), ['product_variant_id' => 'product_variant_id']);
    }
}
