<?php
    
    namespace common\modules\product\models;
    
    use yii\base\Model;
    use yii\data\ActiveDataProvider;
    
    /**
     * ProductVariantSearch represents the model behind the search form about
     * `common\modules\product\models\ProductVariant`.
     */
    class ProductVariantSearch extends ProductVariant
    {
        
        public $variant_name;
        
        public function behaviors()
        {
            return [];
        }
        
        /**
         * @inheritdoc
         */
        public function rules()
        {
            return [
                [
                    [
                        'variant_name',
                        'sku',
                    ],
                    'safe',
                ],
                [
                    [
                        'product_variant_id',
                        'stock',
                    ],
                    'integer',
                ],
                [
                    [
                        'price',
                        'price_old',
                    ],
                    'number',
                ],
            ];
        }
        
        /**
         * @inheritdoc
         */
        public function scenarios()
        {
            // bypass scenarios() implementation in the parent class
            return Model::scenarios();
        }
        
        /**
         * Creates data provider instance with search query applied
         *
         * @param array $params
         *
         * @return ActiveDataProvider
         */
        public function search($params)
        {
            $query = ProductVariant::find()
                                   ->joinWith('lang');
            
            // add conditions that should always apply here
            
            $dataProvider = new ActiveDataProvider([
                'query' => $query,
            ]);
            
            $this->load($params);
            
            if(!$this->validate()) {
                // uncomment the following line if you do not want to return any records when validation fails
                // $query->where('0=1');
                return $dataProvider;
            }
            
            $dataProvider->setSort([
                'attributes' => [
                    'product_variant_id',
                    'sku',
                    'variant_name' => [
                        'asc'  => [ 'product_variant_lang.name' => SORT_ASC ],
                        'desc' => [ 'product_variant_lang.name' => SORT_DESC ],
                    ],
                    'price',
                    'price_old',
                    'stock',
                ],
            ]);
            
            $query->andFilterWhere([
                'price'     => $this->price,
                'price_old' => $this->price_old,
                'stock'     => $this->stock,
            ]);
            
            $query->andFilterWhere([
                'ilike',
                'product_variant_lang.name',
                $this->variant_name,
            ])
                  ->andFilterWhere([
                      'ilike',
                      'sku',
                      $this->sku,
                  ]);
            
            $query->groupBy([
                'product_variant.product_variant_id',
                'product_variant_lang.name',
            ]);
            
            return $dataProvider;
        }
        
        /**
         * @param string $sku
         *
         * @return ProductVariant|null
         */
        public static function findBySku($sku)
        {
            /**
             * @var ProductVariant|null $result
             */
            $result = ProductVariant::find()
                                    ->andWhere([ 'sku' => $sku ])
                                    ->one();
            return $result;
        }
    }
