<?php
    
    namespace common\modules\rubrication\controllers;
    
    use common\modules\rubrication\models\TaxGroup;
    use Yii;
    use common\modules\rubrication\models\TaxOption;
    use common\modules\rubrication\models\TaxOptionSearch;
    use yii\web\Controller;
    use yii\web\NotFoundHttpException;
    use yii\filters\VerbFilter;
    
    /**
     * TaxOptionController implements the CRUD actions for TaxOption model.
     */
    class TaxOptionController extends Controller
    {
        
        /**
         * @inheritdoc
         */
        public function behaviors()
        {
            return [
                'verbs' => [
                    'class'   => VerbFilter::className(),
                    'actions' => [
                        'delete' => [ 'POST' ],
                    ],
                ],
            ];
        }
        
        /**
         * Lists all TaxOption models.
         * @return mixed
         */
        public function actionIndex()
        {
            $group = $this->findGroup(Yii::$app->request->queryParams[ 'group' ]);
            $searchModel = new TaxOptionSearch();
            $dataProvider = $searchModel->search(Yii::$app->request->queryParams);
            $dataProvider->query->andWhere([ 'tax_group_id' => $group->tax_group_id ]);
            if($group->level) {
                $dataProvider->query->with('productVariants');
            } else {
                $dataProvider->query->with('products');
            }
            
            return $this->render('index', [
                'searchModel'  => $searchModel,
                'dataProvider' => $dataProvider,
                'group'        => $group,
            ]);
        }
        
        /**
         * Creates a new TaxOption model.
         * If creation is successful, the browser will be redirected to the 'view' page.
         * @return mixed
         */
        public function actionCreate()
        {
            $group = $this->findGroup(Yii::$app->request->queryParams[ 'group' ]);
            $model = new TaxOption([
                'tax_group_id' => $group->tax_group_id,
            ]);
            $model->generateLangs();
            if($model->load(Yii::$app->request->post())) {
                $model->loadLangs(\Yii::$app->request);
                if($model->save() && $model->transactionStatus) {
                    return is_null(Yii::$app->request->post('create_and_new')) ? $this->redirect([
                        'index',
                        'group' => $group->tax_group_id,
                    ]) : $this->redirect(array_merge([ 'create' ], Yii::$app->request->queryParams));
                }
            }
            if(!empty( Yii::$app->request->queryParams[ 'parent' ] )) {
                $model->parent_id = Yii::$app->request->queryParams[ 'parent' ];
            }
            return $this->render('create', [
                'model'       => $model,
                'model_langs' => $model->model_langs,
                'group'       => $group,
            ]);
        }
        
        /**
         * Updates an existing TaxOption model.
         * If update is successful, the browser will be redirected to the 'view' page.
         *
         * @param string $id
         *
         * @return mixed
         */
        public function actionUpdate($id)
        {
            $model = $this->findModel($id);
            $group = $this->findGroup($model->tax_group_id);
            $model->generateLangs();
            if($model->load(Yii::$app->request->post())) {
                $model->loadLangs(\Yii::$app->request);
                //                TaxOption::find()
                //                         ->rebuildMP($model->tax_group_id);
                if($model->save() && $model->transactionStatus) {
                    return $this->redirect([
                        'index',
                        'group' => $model->tax_group_id,
                    ]);
                }
            }
            return $this->render('update', [
                'model'       => $model,
                'model_langs' => $model->model_langs,
                'group'       => $group,
            ]);
        }
        
        /**
         * Deletes an existing TaxOption model.
         * If deletion is successful, the browser will be redirected to the 'index' page.
         *
         * @param string $id
         *
         * @return mixed
         */
        public function actionDelete($id)
        {
            $model = $this->findModel($id);
            $group_id = $model->tax_group_id;
            
            $model->delete();
            
            return $this->redirect([
                'index',
                'group' => $group_id,
            ]);
        }
        
        /**
         * Finds the TaxOption model based on its primary key value.
         * If the model is not found, a 404 HTTP exception will be thrown.
         *
         * @param string $id
         *
         * @return TaxOption the loaded model
         * @throws NotFoundHttpException if the model cannot be found
         */
        protected function findModel($id)
        {
            if(( $model = TaxOption::find()
                                   ->with('lang')
                                   ->where([ 'tax_option_id' => $id ])
                                   ->one() ) !== NULL
            ) {
                return $model;
            } else {
                throw new NotFoundHttpException('The requested page does not exist.');
            }
        }
        
        /**
         * @param int $id
         *
         * @return null|TaxGroup
         * @throws NotFoundHttpException
         */
        protected function findGroup($id)
        {
            if(( $model = TaxGroup::find()
                                  ->with('lang')
                                  ->where([ 'tax_group_id' => $id ])
                                  ->one() ) !== NULL
            ) {
                return $model;
            } else {
                throw new NotFoundHttpException('The requested page does not exist.');
            }
        }
    }
