<?php
    
    namespace common\modules\rubrication\models;
    
    use common\modules\language\models\Language;
    use Yii;
    
    /**
     * This is the model class for table "tax_group_lang".
     * @property integer  $tax_group_id
     * @property integer  $language_id
     * @property string   $name
     * @property string   $alias
     * @property string   $description
     * @property Language $language
     * @property TaxGroup $taxGroup
     */
    class TaxGroupLang extends \yii\db\ActiveRecord
    {
        
        public static function primaryKey()
        {
            return [
                'tax_group_id',
                'language_id',
            ];
        }
        
        /**
         * @inheritdoc
         */
        public static function tableName()
        {
            return 'tax_group_lang';
        }
        
        public function behaviors()
        {
            return [
                'slug' => [
                    'class'         => 'common\behaviors\Slug',
                    'in_attribute'  => 'name',
                    'out_attribute' => 'alias',
                    'translit'      => true,
                ],
            ];
        }
        
        /**
         * @inheritdoc
         */
        public function rules()
        {
            return [
                [
                    [ 'name' ],
                    'required',
                ],
                [
                    [ 'description' ],
                    'string',
                ],
                [
                    [
                        'name',
                        'alias',
                    ],
                    'string',
                    'max' => 255,
                ],
                [
                    [
                        'tax_group_id',
                        'language_id',
                    ],
                    'unique',
                    'targetAttribute' => [
                        'tax_group_id',
                        'language_id',
                    ],
                    'message'         => 'The combination of Tax Group ID and Language ID has already been taken.',
                ],
                [
                    [ 'language_id' ],
                    'exist',
                    'skipOnError'     => true,
                    'targetClass'     => Language::className(),
                    'targetAttribute' => [ 'language_id' => 'language_id' ],
                ],
                [
                    [ 'tax_group_id' ],
                    'exist',
                    'skipOnError'     => true,
                    'targetClass'     => TaxGroup::className(),
                    'targetAttribute' => [ 'tax_group_id' => 'tax_group_id' ],
                ],
            ];
        }
        
        /**
         * @inheritdoc
         */
        public function attributeLabels()
        {
            return [
                'tax_group_id' => Yii::t('app', 'Tax Group ID'),
                'language_id'  => Yii::t('app', 'Language ID'),
                'name'         => Yii::t('app', 'Name'),
                'description'  => Yii::t('app', 'Description'),
                'alias'        => Yii::t('app', 'Alias'),
            ];
        }
        
        /**
         * @return \yii\db\ActiveQuery
         */
        public function getLanguage()
        {
            return $this->hasOne(Language::className(), [ 'language_id' => 'language_id' ]);
        }
        
        /**
         * @return \yii\db\ActiveQuery
         */
        public function getTaxGroup()
        {
            return $this->hasOne(TaxGroup::className(), [ 'tax_group_id' => 'tax_group_id' ]);
        }
    }
